@@ -9,9 +9,10 @@ from hyphenator import Hyphenator
 from BeautifulSoup import BeautifulSoup, NavigableString
 
 
-def hyphenate_html(html, language='en-us', hyphenator=None, blacklist_tags=(
+def hyphenate(html, language='en-us', hyphenator=None, blacklist_tags=(
     'code', 'tt', 'pre', 'head', 'title', 'script', 'style', 'meta', 'object',
-    'embed', 'samp', 'var', 'math', 'select', 'option', 'input', 'textarea'
+    'embed', 'samp', 'var', 'math', 'select', 'option', 'input', 'textarea',
+    'span',
     )):
     """
     Hyphenate a fragement of HTML
@@ -47,7 +48,7 @@ def hyphenate_html(html, language='en-us', hyphenator=None, blacklist_tags=(
 # Constants
 SOFT_HYPHEN = r'&shy;'
 SPACE = r' '
-STRIP_WHITESPACE = re.compile('\w+', re.MULTILINE)
+STRIP_WHITESPACE = re.compile('\w+', re.MULTILINE|re.UNICODE)
 
 def hyphenate_element(soup, hyphenator, blacklist_tags):
     """
